# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from .._models import BaseModel

__all__ = ["ListEnvironmentListResponse", "ListEnvironmentListResponseItem"]


class ListEnvironmentListResponseItem(BaseModel):
    id: str

    description: str

    gpu: bool

    languages: List[str]

    name: str

    version: str

    is_custom: Optional[bool] = None

    os: Optional[str] = None


ListEnvironmentListResponse: TypeAlias = List[ListEnvironmentListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["RunRunFlowResponse"]


class RunRunFlowResponse(BaseModel):
    flow_status: str

    run_number: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["AuthSessionLoginResponse"]


class AuthSessionLoginResponse(BaseModel):
    email: str

    storage_bucket: str

    uid: str

    display_name: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .run_status import RunStatus

__all__ = ["RunGetRunMetadataResponse"]


class RunGetRunMetadataResponse(BaseModel):
    id: str

    date_created: str

    date_modified: Optional[str] = None

    description: Optional[str] = None

    name: str

    run_folder: str

    run_number: int

    metadata_version: Optional[str] = None

    mlflow_experiment_id: Optional[str] = None

    mlflow_run_id: Optional[str] = None

    run_status: Optional[RunStatus] = None

    tags: Optional[List[str]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ssh import (
    SSHResource,
    AsyncSSHResource,
    SSHResourceWithRawResponse,
    AsyncSSHResourceWithRawResponse,
    SSHResourceWithStreamingResponse,
    AsyncSSHResourceWithStreamingResponse,
)
from .auth import (
    AuthResource,
    AsyncAuthResource,
    AuthResourceWithRawResponse,
    AsyncAuthResourceWithRawResponse,
    AuthResourceWithStreamingResponse,
    AsyncAuthResourceWithStreamingResponse,
)

__all__ = [
    "SSHResource",
    "AsyncSSHResource",
    "SSHResourceWithRawResponse",
    "AsyncSSHResourceWithRawResponse",
    "SSHResourceWithStreamingResponse",
    "AsyncSSHResourceWithStreamingResponse",
    "AuthResource",
    "AsyncAuthResource",
    "AuthResourceWithRawResponse",
    "AsyncAuthResourceWithRawResponse",
    "AuthResourceWithStreamingResponse",
    "AsyncAuthResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["FileGetProjectNodePathParams"]


class FileGetProjectNodePathParams(TypedDict, total=False):
    id: Required[str]

    node_id: Required[str]

    description: str

    label: str

    location: str

    metadata_version: str

    status: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .utils import (
    UtilsResource,
    AsyncUtilsResource,
    UtilsResourceWithRawResponse,
    AsyncUtilsResourceWithRawResponse,
    UtilsResourceWithStreamingResponse,
    AsyncUtilsResourceWithStreamingResponse,
)
from .retrieval_mode import (
    RetrievalModeResource,
    AsyncRetrievalModeResource,
    RetrievalModeResourceWithRawResponse,
    AsyncRetrievalModeResourceWithRawResponse,
    RetrievalModeResourceWithStreamingResponse,
    AsyncRetrievalModeResourceWithStreamingResponse,
)

__all__ = [
    "RetrievalModeResource",
    "AsyncRetrievalModeResource",
    "RetrievalModeResourceWithRawResponse",
    "AsyncRetrievalModeResourceWithRawResponse",
    "RetrievalModeResourceWithStreamingResponse",
    "AsyncRetrievalModeResourceWithStreamingResponse",
    "UtilsResource",
    "AsyncUtilsResource",
    "UtilsResourceWithRawResponse",
    "AsyncUtilsResourceWithRawResponse",
    "UtilsResourceWithStreamingResponse",
    "AsyncUtilsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .logs import (
    LogsResource,
    AsyncLogsResource,
    LogsResourceWithRawResponse,
    AsyncLogsResourceWithRawResponse,
    LogsResourceWithStreamingResponse,
    AsyncLogsResourceWithStreamingResponse,
)
from ...types import (
    run_list_params,
    run_run_flow_params,
    run_get_properties_params,
    run_fetch_run_nodes_params,
    run_list_node_outputs_params,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.run_list_response import RunListResponse
from ...types.project_summary_param import ProjectSummaryParam
from ...types.run_run_flow_response import RunRunFlowResponse
from ...types.run_get_properties_response import RunGetPropertiesResponse
from ...types.run_fetch_run_nodes_response import RunFetchRunNodesResponse
from ...types.run_get_run_metadata_response import RunGetRunMetadataResponse
from ...types.run_list_node_outputs_response import RunListNodeOutputsResponse

__all__ = ["RunsResource", "AsyncRunsResource"]


class RunsResource(SyncAPIResource):
    @cached_property
    def logs(self) -> LogsResource:
        return LogsResource(self._client)

    @cached_property
    def with_raw_response(self) -> RunsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return RunsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RunsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return RunsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunListResponse:
        """
        List Runs

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/runs/list_runs",
            body=maybe_transform(
                {
                    "id": id,
                    "description": description,
                    "label": label,
                    "location": location,
                    "metadata_version": metadata_version,
                    "status": status,
                },
                run_list_params.RunListParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RunListResponse,
        )

    def fetch_run_nodes(
        self,
        run_folder: str,
        *,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunFetchRunNodesResponse:
        """
        Fetch Nodes for a Given Run

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not run_folder:
            raise ValueError(f"Expected a non-empty value for `run_folder` but received {run_folder!r}")
        return self._get(
            f"/runs/fetch_run_nodes/{run_folder}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "id": id,
                        "description": description,
                        "label": label,
                        "location": location,
                        "metadata_version": metadata_version,
                        "status": status,
                    },
                    run_fetch_run_nodes_params.RunFetchRunNodesParams,
                ),
            ),
            cast_to=RunFetchRunNodesResponse,
        )

    def get_file(
        self,
        path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve and stream a file from the specified path.

        Args: path: Path to the file relative to the storage root

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path:
            raise ValueError(f"Expected a non-empty value for `path` but received {path!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/runs/file/{path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_properties(
        self,
        run_folder: str,
        *,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunGetPropertiesResponse:
        """
        Get properties for a specific run.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not run_folder:
            raise ValueError(f"Expected a non-empty value for `run_folder` but received {run_folder!r}")
        return self._get(
            f"/runs/get_runs_properties/{run_folder}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "id": id,
                        "description": description,
                        "label": label,
                        "location": location,
                        "metadata_version": metadata_version,
                        "status": status,
                    },
                    run_get_properties_params.RunGetPropertiesParams,
                ),
            ),
            cast_to=RunGetPropertiesResponse,
        )

    def get_run_metadata(
        self,
        run_number: int,
        *,
        project_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunGetRunMetadataResponse:
        """
        Get properties for a specific run.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not project_id:
            raise ValueError(f"Expected a non-empty value for `project_id` but received {project_id!r}")
        return self._get(
            f"/runs/get_run_metadata/{project_id}/{run_number}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RunGetRunMetadataResponse,
        )

    def list_node_outputs(
        self,
        node_id: str,
        *,
        run_number: int,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunListNodeOutputsResponse:
        """
        List all output files for a specific node in a run, including files in
        subdirectories (1 level deep).

        Args: run_number: The run number node_id: The node ID to list outputs for
        project: The project containing the run

        Returns: List of relative file paths within the node's output directory
        (including subdirectories)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not node_id:
            raise ValueError(f"Expected a non-empty value for `node_id` but received {node_id!r}")
        return self._get(
            f"/runs/list_node_outputs/{run_number}/{node_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "id": id,
                        "description": description,
                        "label": label,
                        "location": location,
                        "metadata_version": metadata_version,
                        "status": status,
                    },
                    run_list_node_outputs_params.RunListNodeOutputsParams,
                ),
            ),
            cast_to=RunListNodeOutputsResponse,
        )

    def run_flow(
        self,
        *,
        payload: run_run_flow_params.Payload,
        project: ProjectSummaryParam,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunRunFlowResponse:
        """
        Run Flow

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/runs/run_flow",
            body=maybe_transform(
                {
                    "payload": payload,
                    "project": project,
                },
                run_run_flow_params.RunRunFlowParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RunRunFlowResponse,
        )


class AsyncRunsResource(AsyncAPIResource):
    @cached_property
    def logs(self) -> AsyncLogsResource:
        return AsyncLogsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncRunsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncRunsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRunsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncRunsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunListResponse:
        """
        List Runs

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/runs/list_runs",
            body=await async_maybe_transform(
                {
                    "id": id,
                    "description": description,
                    "label": label,
                    "location": location,
                    "metadata_version": metadata_version,
                    "status": status,
                },
                run_list_params.RunListParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RunListResponse,
        )

    async def fetch_run_nodes(
        self,
        run_folder: str,
        *,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunFetchRunNodesResponse:
        """
        Fetch Nodes for a Given Run

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not run_folder:
            raise ValueError(f"Expected a non-empty value for `run_folder` but received {run_folder!r}")
        return await self._get(
            f"/runs/fetch_run_nodes/{run_folder}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "id": id,
                        "description": description,
                        "label": label,
                        "location": location,
                        "metadata_version": metadata_version,
                        "status": status,
                    },
                    run_fetch_run_nodes_params.RunFetchRunNodesParams,
                ),
            ),
            cast_to=RunFetchRunNodesResponse,
        )

    async def get_file(
        self,
        path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retrieve and stream a file from the specified path.

        Args: path: Path to the file relative to the storage root

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path:
            raise ValueError(f"Expected a non-empty value for `path` but received {path!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/runs/file/{path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_properties(
        self,
        run_folder: str,
        *,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunGetPropertiesResponse:
        """
        Get properties for a specific run.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not run_folder:
            raise ValueError(f"Expected a non-empty value for `run_folder` but received {run_folder!r}")
        return await self._get(
            f"/runs/get_runs_properties/{run_folder}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "id": id,
                        "description": description,
                        "label": label,
                        "location": location,
                        "metadata_version": metadata_version,
                        "status": status,
                    },
                    run_get_properties_params.RunGetPropertiesParams,
                ),
            ),
            cast_to=RunGetPropertiesResponse,
        )

    async def get_run_metadata(
        self,
        run_number: int,
        *,
        project_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunGetRunMetadataResponse:
        """
        Get properties for a specific run.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not project_id:
            raise ValueError(f"Expected a non-empty value for `project_id` but received {project_id!r}")
        return await self._get(
            f"/runs/get_run_metadata/{project_id}/{run_number}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RunGetRunMetadataResponse,
        )

    async def list_node_outputs(
        self,
        node_id: str,
        *,
        run_number: int,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunListNodeOutputsResponse:
        """
        List all output files for a specific node in a run, including files in
        subdirectories (1 level deep).

        Args: run_number: The run number node_id: The node ID to list outputs for
        project: The project containing the run

        Returns: List of relative file paths within the node's output directory
        (including subdirectories)

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not node_id:
            raise ValueError(f"Expected a non-empty value for `node_id` but received {node_id!r}")
        return await self._get(
            f"/runs/list_node_outputs/{run_number}/{node_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "id": id,
                        "description": description,
                        "label": label,
                        "location": location,
                        "metadata_version": metadata_version,
                        "status": status,
                    },
                    run_list_node_outputs_params.RunListNodeOutputsParams,
                ),
            ),
            cast_to=RunListNodeOutputsResponse,
        )

    async def run_flow(
        self,
        *,
        payload: run_run_flow_params.Payload,
        project: ProjectSummaryParam,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RunRunFlowResponse:
        """
        Run Flow

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/runs/run_flow",
            body=await async_maybe_transform(
                {
                    "payload": payload,
                    "project": project,
                },
                run_run_flow_params.RunRunFlowParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RunRunFlowResponse,
        )


class RunsResourceWithRawResponse:
    def __init__(self, runs: RunsResource) -> None:
        self._runs = runs

        self.list = to_raw_response_wrapper(
            runs.list,
        )
        self.fetch_run_nodes = to_raw_response_wrapper(
            runs.fetch_run_nodes,
        )
        self.get_file = to_raw_response_wrapper(
            runs.get_file,
        )
        self.get_properties = to_raw_response_wrapper(
            runs.get_properties,
        )
        self.get_run_metadata = to_raw_response_wrapper(
            runs.get_run_metadata,
        )
        self.list_node_outputs = to_raw_response_wrapper(
            runs.list_node_outputs,
        )
        self.run_flow = to_raw_response_wrapper(
            runs.run_flow,
        )

    @cached_property
    def logs(self) -> LogsResourceWithRawResponse:
        return LogsResourceWithRawResponse(self._runs.logs)


class AsyncRunsResourceWithRawResponse:
    def __init__(self, runs: AsyncRunsResource) -> None:
        self._runs = runs

        self.list = async_to_raw_response_wrapper(
            runs.list,
        )
        self.fetch_run_nodes = async_to_raw_response_wrapper(
            runs.fetch_run_nodes,
        )
        self.get_file = async_to_raw_response_wrapper(
            runs.get_file,
        )
        self.get_properties = async_to_raw_response_wrapper(
            runs.get_properties,
        )
        self.get_run_metadata = async_to_raw_response_wrapper(
            runs.get_run_metadata,
        )
        self.list_node_outputs = async_to_raw_response_wrapper(
            runs.list_node_outputs,
        )
        self.run_flow = async_to_raw_response_wrapper(
            runs.run_flow,
        )

    @cached_property
    def logs(self) -> AsyncLogsResourceWithRawResponse:
        return AsyncLogsResourceWithRawResponse(self._runs.logs)


class RunsResourceWithStreamingResponse:
    def __init__(self, runs: RunsResource) -> None:
        self._runs = runs

        self.list = to_streamed_response_wrapper(
            runs.list,
        )
        self.fetch_run_nodes = to_streamed_response_wrapper(
            runs.fetch_run_nodes,
        )
        self.get_file = to_streamed_response_wrapper(
            runs.get_file,
        )
        self.get_properties = to_streamed_response_wrapper(
            runs.get_properties,
        )
        self.get_run_metadata = to_streamed_response_wrapper(
            runs.get_run_metadata,
        )
        self.list_node_outputs = to_streamed_response_wrapper(
            runs.list_node_outputs,
        )
        self.run_flow = to_streamed_response_wrapper(
            runs.run_flow,
        )

    @cached_property
    def logs(self) -> LogsResourceWithStreamingResponse:
        return LogsResourceWithStreamingResponse(self._runs.logs)


class AsyncRunsResourceWithStreamingResponse:
    def __init__(self, runs: AsyncRunsResource) -> None:
        self._runs = runs

        self.list = async_to_streamed_response_wrapper(
            runs.list,
        )
        self.fetch_run_nodes = async_to_streamed_response_wrapper(
            runs.fetch_run_nodes,
        )
        self.get_file = async_to_streamed_response_wrapper(
            runs.get_file,
        )
        self.get_properties = async_to_streamed_response_wrapper(
            runs.get_properties,
        )
        self.get_run_metadata = async_to_streamed_response_wrapper(
            runs.get_run_metadata,
        )
        self.list_node_outputs = async_to_streamed_response_wrapper(
            runs.list_node_outputs,
        )
        self.run_flow = async_to_streamed_response_wrapper(
            runs.run_flow,
        )

    @cached_property
    def logs(self) -> AsyncLogsResourceWithStreamingResponse:
        return AsyncLogsResourceWithStreamingResponse(self._runs.logs)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["GraphNode", "Data", "Position"]


class Data(BaseModel):
    label: str

    simulation_id: Optional[str] = None


class Position(BaseModel):
    x: float

    y: float


class GraphNode(BaseModel):
    id: str

    data: Data
    """Extra metadata for a node."""

    position: Position
    """Position of a node in layout space."""

    type: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["UpsertSimulationCreateResponse"]


class UpsertSimulationCreateResponse(BaseModel):
    redirect_url: str

    status: Literal["success", "error"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["FileLoadEditorFileResponse"]


class FileLoadEditorFileResponse(BaseModel):
    filename: str

    language: str

    mime_type: str

    path: str

    size: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .graph_node_param import GraphNodeParam
from .project_summary_param import ProjectSummaryParam

__all__ = ["GraphInsertNodeParams"]


class GraphInsertNodeParams(TypedDict, total=False):
    node: Required[GraphNodeParam]
    """A node in the graph.

    Attributes: id: Unique node ID. position: Node position. data: Extra metadata.
    type: Renderer/type key.
    """

    project: Required[ProjectSummaryParam]

    sim_global: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from fluidize_sdk import FluidizeSDK, AsyncFluidizeSDK
from fluidize_sdk.types.auth import SSHConnectResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSSH:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_connect(self, client: FluidizeSDK) -> None:
        ssh = client.auth.ssh.connect(
            password="password",
            username="username",
            verification_code="verification_code",
        )
        assert_matches_type(SSHConnectResponse, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_connect_with_all_params(self, client: FluidizeSDK) -> None:
        ssh = client.auth.ssh.connect(
            password="password",
            username="username",
            verification_code="verification_code",
            host="host",
            port=0,
        )
        assert_matches_type(SSHConnectResponse, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_connect(self, client: FluidizeSDK) -> None:
        response = client.auth.ssh.with_raw_response.connect(
            password="password",
            username="username",
            verification_code="verification_code",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ssh = response.parse()
        assert_matches_type(SSHConnectResponse, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_connect(self, client: FluidizeSDK) -> None:
        with client.auth.ssh.with_streaming_response.connect(
            password="password",
            username="username",
            verification_code="verification_code",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ssh = response.parse()
            assert_matches_type(SSHConnectResponse, ssh, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_disconnect(self, client: FluidizeSDK) -> None:
        ssh = client.auth.ssh.disconnect()
        assert_matches_type(object, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_disconnect(self, client: FluidizeSDK) -> None:
        response = client.auth.ssh.with_raw_response.disconnect()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ssh = response.parse()
        assert_matches_type(object, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_disconnect(self, client: FluidizeSDK) -> None:
        with client.auth.ssh.with_streaming_response.disconnect() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ssh = response.parse()
            assert_matches_type(object, ssh, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_status(self, client: FluidizeSDK) -> None:
        ssh = client.auth.ssh.status()
        assert_matches_type(object, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_status(self, client: FluidizeSDK) -> None:
        response = client.auth.ssh.with_raw_response.status()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ssh = response.parse()
        assert_matches_type(object, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_status(self, client: FluidizeSDK) -> None:
        with client.auth.ssh.with_streaming_response.status() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ssh = response.parse()
            assert_matches_type(object, ssh, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSSH:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_connect(self, async_client: AsyncFluidizeSDK) -> None:
        ssh = await async_client.auth.ssh.connect(
            password="password",
            username="username",
            verification_code="verification_code",
        )
        assert_matches_type(SSHConnectResponse, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_connect_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        ssh = await async_client.auth.ssh.connect(
            password="password",
            username="username",
            verification_code="verification_code",
            host="host",
            port=0,
        )
        assert_matches_type(SSHConnectResponse, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_connect(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.auth.ssh.with_raw_response.connect(
            password="password",
            username="username",
            verification_code="verification_code",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ssh = await response.parse()
        assert_matches_type(SSHConnectResponse, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_connect(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.auth.ssh.with_streaming_response.connect(
            password="password",
            username="username",
            verification_code="verification_code",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ssh = await response.parse()
            assert_matches_type(SSHConnectResponse, ssh, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_disconnect(self, async_client: AsyncFluidizeSDK) -> None:
        ssh = await async_client.auth.ssh.disconnect()
        assert_matches_type(object, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_disconnect(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.auth.ssh.with_raw_response.disconnect()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ssh = await response.parse()
        assert_matches_type(object, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_disconnect(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.auth.ssh.with_streaming_response.disconnect() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ssh = await response.parse()
            assert_matches_type(object, ssh, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_status(self, async_client: AsyncFluidizeSDK) -> None:
        ssh = await async_client.auth.ssh.status()
        assert_matches_type(object, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_status(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.auth.ssh.with_raw_response.status()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ssh = await response.parse()
        assert_matches_type(object, ssh, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_status(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.auth.ssh.with_streaming_response.status() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ssh = await response.parse()
            assert_matches_type(object, ssh, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import TypeAlias

from .._models import BaseModel
from .run_status import RunStatus

__all__ = ["RunGetPropertiesResponse", "RunGetPropertiesResponseItem"]


class RunGetPropertiesResponseItem(BaseModel):
    container_image: str

    node_id: str
    """Node ID is always the folder name where this node exists"""

    output_path: str

    simulation_mount_path: str

    last_run: Optional[str] = None

    properties_version: Optional[str] = None

    run_status: Optional[RunStatus] = None

    should_run: Optional[bool] = None

    source_output_folder: Optional[str] = None

    version: Union[str, float, None] = None


RunGetPropertiesResponse: TypeAlias = List[RunGetPropertiesResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from fluidize_sdk import FluidizeSDK, AsyncFluidizeSDK
from fluidize_sdk.types import (
    RunListResponse,
    RunRunFlowResponse,
    RunFetchRunNodesResponse,
    RunGetPropertiesResponse,
    RunGetRunMetadataResponse,
    RunListNodeOutputsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestRuns:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: FluidizeSDK) -> None:
        run = client.runs.list(
            id="id",
        )
        assert_matches_type(RunListResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: FluidizeSDK) -> None:
        run = client.runs.list(
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(RunListResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: FluidizeSDK) -> None:
        response = client.runs.with_raw_response.list(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunListResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: FluidizeSDK) -> None:
        with client.runs.with_streaming_response.list(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunListResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_fetch_run_nodes(self, client: FluidizeSDK) -> None:
        run = client.runs.fetch_run_nodes(
            run_folder="run_folder",
            id="id",
        )
        assert_matches_type(RunFetchRunNodesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_fetch_run_nodes_with_all_params(self, client: FluidizeSDK) -> None:
        run = client.runs.fetch_run_nodes(
            run_folder="run_folder",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(RunFetchRunNodesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_fetch_run_nodes(self, client: FluidizeSDK) -> None:
        response = client.runs.with_raw_response.fetch_run_nodes(
            run_folder="run_folder",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunFetchRunNodesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_fetch_run_nodes(self, client: FluidizeSDK) -> None:
        with client.runs.with_streaming_response.fetch_run_nodes(
            run_folder="run_folder",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunFetchRunNodesResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_fetch_run_nodes(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_folder` but received ''"):
            client.runs.with_raw_response.fetch_run_nodes(
                run_folder="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_file(self, client: FluidizeSDK) -> None:
        run = client.runs.get_file(
            "path",
        )
        assert run is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_file(self, client: FluidizeSDK) -> None:
        response = client.runs.with_raw_response.get_file(
            "path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert run is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_file(self, client: FluidizeSDK) -> None:
        with client.runs.with_streaming_response.get_file(
            "path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert run is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_file(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path` but received ''"):
            client.runs.with_raw_response.get_file(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_properties(self, client: FluidizeSDK) -> None:
        run = client.runs.get_properties(
            run_folder="run_folder",
            id="id",
        )
        assert_matches_type(RunGetPropertiesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_properties_with_all_params(self, client: FluidizeSDK) -> None:
        run = client.runs.get_properties(
            run_folder="run_folder",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(RunGetPropertiesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_properties(self, client: FluidizeSDK) -> None:
        response = client.runs.with_raw_response.get_properties(
            run_folder="run_folder",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunGetPropertiesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_properties(self, client: FluidizeSDK) -> None:
        with client.runs.with_streaming_response.get_properties(
            run_folder="run_folder",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunGetPropertiesResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_properties(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_folder` but received ''"):
            client.runs.with_raw_response.get_properties(
                run_folder="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_run_metadata(self, client: FluidizeSDK) -> None:
        run = client.runs.get_run_metadata(
            run_number=0,
            project_id="project_id",
        )
        assert_matches_type(RunGetRunMetadataResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_run_metadata(self, client: FluidizeSDK) -> None:
        response = client.runs.with_raw_response.get_run_metadata(
            run_number=0,
            project_id="project_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunGetRunMetadataResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_run_metadata(self, client: FluidizeSDK) -> None:
        with client.runs.with_streaming_response.get_run_metadata(
            run_number=0,
            project_id="project_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunGetRunMetadataResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_run_metadata(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `project_id` but received ''"):
            client.runs.with_raw_response.get_run_metadata(
                run_number=0,
                project_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_node_outputs(self, client: FluidizeSDK) -> None:
        run = client.runs.list_node_outputs(
            node_id="node_id",
            run_number=0,
            id="id",
        )
        assert_matches_type(RunListNodeOutputsResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_node_outputs_with_all_params(self, client: FluidizeSDK) -> None:
        run = client.runs.list_node_outputs(
            node_id="node_id",
            run_number=0,
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(RunListNodeOutputsResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_node_outputs(self, client: FluidizeSDK) -> None:
        response = client.runs.with_raw_response.list_node_outputs(
            node_id="node_id",
            run_number=0,
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunListNodeOutputsResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_node_outputs(self, client: FluidizeSDK) -> None:
        with client.runs.with_streaming_response.list_node_outputs(
            node_id="node_id",
            run_number=0,
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunListNodeOutputsResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list_node_outputs(self, client: FluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `node_id` but received ''"):
            client.runs.with_raw_response.list_node_outputs(
                node_id="",
                run_number=0,
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_run_flow(self, client: FluidizeSDK) -> None:
        run = client.runs.run_flow(
            payload={},
            project={"id": "id"},
        )
        assert_matches_type(RunRunFlowResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_run_flow_with_all_params(self, client: FluidizeSDK) -> None:
        run = client.runs.run_flow(
            payload={
                "description": "description",
                "name": "name",
                "tags": ["string"],
            },
            project={
                "id": "id",
                "description": "description",
                "label": "label",
                "location": "location",
                "metadata_version": "metadata_version",
                "status": "status",
            },
        )
        assert_matches_type(RunRunFlowResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_run_flow(self, client: FluidizeSDK) -> None:
        response = client.runs.with_raw_response.run_flow(
            payload={},
            project={"id": "id"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunRunFlowResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_run_flow(self, client: FluidizeSDK) -> None:
        with client.runs.with_streaming_response.run_flow(
            payload={},
            project={"id": "id"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunRunFlowResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncRuns:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.list(
            id="id",
        )
        assert_matches_type(RunListResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.list(
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(RunListResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.runs.with_raw_response.list(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunListResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.runs.with_streaming_response.list(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunListResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_fetch_run_nodes(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.fetch_run_nodes(
            run_folder="run_folder",
            id="id",
        )
        assert_matches_type(RunFetchRunNodesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_fetch_run_nodes_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.fetch_run_nodes(
            run_folder="run_folder",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(RunFetchRunNodesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_fetch_run_nodes(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.runs.with_raw_response.fetch_run_nodes(
            run_folder="run_folder",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunFetchRunNodesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_fetch_run_nodes(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.runs.with_streaming_response.fetch_run_nodes(
            run_folder="run_folder",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunFetchRunNodesResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_fetch_run_nodes(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_folder` but received ''"):
            await async_client.runs.with_raw_response.fetch_run_nodes(
                run_folder="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_file(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.get_file(
            "path",
        )
        assert run is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_file(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.runs.with_raw_response.get_file(
            "path",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert run is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_file(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.runs.with_streaming_response.get_file(
            "path",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert run is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_file(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path` but received ''"):
            await async_client.runs.with_raw_response.get_file(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_properties(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.get_properties(
            run_folder="run_folder",
            id="id",
        )
        assert_matches_type(RunGetPropertiesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_properties_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.get_properties(
            run_folder="run_folder",
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(RunGetPropertiesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_properties(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.runs.with_raw_response.get_properties(
            run_folder="run_folder",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunGetPropertiesResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_properties(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.runs.with_streaming_response.get_properties(
            run_folder="run_folder",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunGetPropertiesResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_properties(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_folder` but received ''"):
            await async_client.runs.with_raw_response.get_properties(
                run_folder="",
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_run_metadata(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.get_run_metadata(
            run_number=0,
            project_id="project_id",
        )
        assert_matches_type(RunGetRunMetadataResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_run_metadata(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.runs.with_raw_response.get_run_metadata(
            run_number=0,
            project_id="project_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunGetRunMetadataResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_run_metadata(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.runs.with_streaming_response.get_run_metadata(
            run_number=0,
            project_id="project_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunGetRunMetadataResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_run_metadata(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `project_id` but received ''"):
            await async_client.runs.with_raw_response.get_run_metadata(
                run_number=0,
                project_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_node_outputs(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.list_node_outputs(
            node_id="node_id",
            run_number=0,
            id="id",
        )
        assert_matches_type(RunListNodeOutputsResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_node_outputs_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.list_node_outputs(
            node_id="node_id",
            run_number=0,
            id="id",
            description="description",
            label="label",
            location="location",
            metadata_version="metadata_version",
            status="status",
        )
        assert_matches_type(RunListNodeOutputsResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_node_outputs(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.runs.with_raw_response.list_node_outputs(
            node_id="node_id",
            run_number=0,
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunListNodeOutputsResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_node_outputs(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.runs.with_streaming_response.list_node_outputs(
            node_id="node_id",
            run_number=0,
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunListNodeOutputsResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list_node_outputs(self, async_client: AsyncFluidizeSDK) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `node_id` but received ''"):
            await async_client.runs.with_raw_response.list_node_outputs(
                node_id="",
                run_number=0,
                id="id",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_run_flow(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.run_flow(
            payload={},
            project={"id": "id"},
        )
        assert_matches_type(RunRunFlowResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_run_flow_with_all_params(self, async_client: AsyncFluidizeSDK) -> None:
        run = await async_client.runs.run_flow(
            payload={
                "description": "description",
                "name": "name",
                "tags": ["string"],
            },
            project={
                "id": "id",
                "description": "description",
                "label": "label",
                "location": "location",
                "metadata_version": "metadata_version",
                "status": "status",
            },
        )
        assert_matches_type(RunRunFlowResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_run_flow(self, async_client: AsyncFluidizeSDK) -> None:
        response = await async_client.runs.with_raw_response.run_flow(
            payload={},
            project={"id": "id"},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunRunFlowResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_run_flow(self, async_client: AsyncFluidizeSDK) -> None:
        async with async_client.runs.with_streaming_response.run_flow(
            payload={},
            project={"id": "id"},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunRunFlowResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["GraphEdge"]


class GraphEdge(BaseModel):
    id: str

    source: str

    target: str

    type: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .parameter import Parameter as Parameter
from .graph_edge import GraphEdge as GraphEdge
from .graph_node import GraphNode as GraphNode
from .run_status import RunStatus as RunStatus
from .signed_url import SignedURL as SignedURL
from .parameter_param import ParameterParam as ParameterParam
from .project_summary import ProjectSummary as ProjectSummary
from .run_list_params import RunListParams as RunListParams
from .graph_node_param import GraphNodeParam as GraphNodeParam
from .graph_sync_params import GraphSyncParams as GraphSyncParams
from .run_list_response import RunListResponse as RunListResponse
from .save_file_response import SaveFileResponse as SaveFileResponse
from .run_run_flow_params import RunRunFlowParams as RunRunFlowParams
from .graph_retrieve_params import GraphRetrieveParams as GraphRetrieveParams
from .project_list_response import ProjectListResponse as ProjectListResponse
from .project_summary_param import ProjectSummaryParam as ProjectSummaryParam
from .project_upsert_params import ProjectUpsertParams as ProjectUpsertParams
from .run_run_flow_response import RunRunFlowResponse as RunRunFlowResponse
from .graph_retrieve_response import GraphRetrieveResponse as GraphRetrieveResponse
from .graph_delete_edge_params import GraphDeleteEdgeParams as GraphDeleteEdgeParams
from .graph_delete_node_params import GraphDeleteNodeParams as GraphDeleteNodeParams
from .graph_insert_node_params import GraphInsertNodeParams as GraphInsertNodeParams
from .graph_upsert_edge_params import GraphUpsertEdgeParams as GraphUpsertEdgeParams
from .node_metadata_simulation import NodeMetadataSimulation as NodeMetadataSimulation
from .auth_session_login_params import AuthSessionLoginParams as AuthSessionLoginParams
from .run_get_properties_params import RunGetPropertiesParams as RunGetPropertiesParams
from .run_fetch_run_nodes_params import RunFetchRunNodesParams as RunFetchRunNodesParams
from .auth_session_login_response import AuthSessionLoginResponse as AuthSessionLoginResponse
from .graph_get_parameters_params import GraphGetParametersParams as GraphGetParametersParams
from .graph_set_parameters_params import GraphSetParametersParams as GraphSetParametersParams
from .run_get_properties_response import RunGetPropertiesResponse as RunGetPropertiesResponse
from .file_list_directory_response import FileListDirectoryResponse as FileListDirectoryResponse
from .file_save_editor_file_params import FileSaveEditorFileParams as FileSaveEditorFileParams
from .run_fetch_run_nodes_response import RunFetchRunNodesResponse as RunFetchRunNodesResponse
from .run_list_node_outputs_params import RunListNodeOutputsParams as RunListNodeOutputsParams
from .file_save_file_content_params import FileSaveFileContentParams as FileSaveFileContentParams
from .graph_get_parameters_response import GraphGetParametersResponse as GraphGetParametersResponse
from .graph_set_parameters_response import GraphSetParametersResponse as GraphSetParametersResponse
from .graph_upsert_parameter_params import GraphUpsertParameterParams as GraphUpsertParameterParams
from .run_get_run_metadata_response import RunGetRunMetadataResponse as RunGetRunMetadataResponse
from .file_load_editor_file_response import FileLoadEditorFileResponse as FileLoadEditorFileResponse
from .list_environment_list_response import ListEnvironmentListResponse as ListEnvironmentListResponse
from .run_list_node_outputs_response import RunListNodeOutputsResponse as RunListNodeOutputsResponse
from .test_connection_check_response import TestConnectionCheckResponse as TestConnectionCheckResponse
from .file_get_simulation_path_params import FileGetSimulationPathParams as FileGetSimulationPathParams
from .upsert_simulation_create_params import UpsertSimulationCreateParams as UpsertSimulationCreateParams
from .file_get_project_node_path_params import FileGetProjectNodePathParams as FileGetProjectNodePathParams
from .file_get_simulation_path_response import FileGetSimulationPathResponse as FileGetSimulationPathResponse
from .graph_update_node_position_params import GraphUpdateNodePositionParams as GraphUpdateNodePositionParams
from .upsert_simulation_create_response import UpsertSimulationCreateResponse as UpsertSimulationCreateResponse
from .simulation_list_simulations_params import SimulationListSimulationsParams as SimulationListSimulationsParams
from .file_get_project_node_path_response import FileGetProjectNodePathResponse as FileGetProjectNodePathResponse
from .simulation_list_simulations_response import SimulationListSimulationsResponse as SimulationListSimulationsResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["GraphUpsertEdgeParams"]


class GraphUpsertEdgeParams(TypedDict, total=False):
    query_id: Required[Annotated[str, PropertyInfo(alias="id")]]

    body_id: Required[Annotated[str, PropertyInfo(alias="id")]]

    source: Required[str]

    target: Required[str]

    type: Required[str]

    description: str

    label: str

    location: str

    metadata_version: str

    status: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["RunStatus"]

RunStatus: TypeAlias = Literal["NOT_RUN", "RUNNING", "FAILED", "SUCCESS"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    file_save_editor_file_params,
    file_save_file_content_params,
    file_get_simulation_path_params,
    file_get_project_node_path_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.signed_url import SignedURL
from ..types.save_file_response import SaveFileResponse
from ..types.file_list_directory_response import FileListDirectoryResponse
from ..types.file_load_editor_file_response import FileLoadEditorFileResponse

__all__ = ["FilesResource", "AsyncFilesResource"]


class FilesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> FilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return FilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return FilesResourceWithStreamingResponse(self)

    def fetch_download_signed_url(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SignedURL:
        """
        Generate a signed URL for downloading a file from cloud storage.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return self._get(
            f"/files/fetch-download-signed-url/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SignedURL,
        )

    def fetch_upload_signed_url(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SignedURL:
        """
        Generate a signed URL for uploading a file to cloud storage.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return self._get(
            f"/files/fetch-upload-signed-url/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SignedURL,
        )

    def get_project_node_path(
        self,
        *,
        id: str,
        node_id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Get the path for a node within a specific project.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/files/get_project_node_path/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "id": id,
                        "node_id": node_id,
                        "description": description,
                        "label": label,
                        "location": location,
                        "metadata_version": metadata_version,
                        "status": status,
                    },
                    file_get_project_node_path_params.FileGetProjectNodePathParams,
                ),
            ),
            cast_to=str,
        )

    def get_simulation_path(
        self,
        *,
        node_id: str,
        sim_global: bool,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Get the initial directory response for simulations (global or user-specific).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/files/get_simulation_path/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "node_id": node_id,
                        "sim_global": sim_global,
                    },
                    file_get_simulation_path_params.FileGetSimulationPathParams,
                ),
            ),
            cast_to=str,
        )

    def list_directory(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FileListDirectoryResponse:
        """
        List the contents of a directory for a given file path

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return self._get(
            f"/files/list-directory/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileListDirectoryResponse,
        )

    def load_editor_file(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FileLoadEditorFileResponse:
        """
        Load a file from a specific path for the editor.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return self._get(
            f"/files/load-editor-file/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileLoadEditorFileResponse,
        )

    def save_editor_file(
        self,
        *,
        content: str,
        path: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SaveFileResponse:
        """
        Save content to a file in the editor.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/files/save-editor-file",
            body=maybe_transform(
                {
                    "content": content,
                    "path": path,
                },
                file_save_editor_file_params.FileSaveEditorFileParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SaveFileResponse,
        )

    def save_file_content(
        self,
        file_path: str,
        *,
        content: str,
        path: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SaveFileResponse:
        """
        Save content to a file in the editor.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return self._post(
            f"/files/content/{file_path}",
            body=maybe_transform(
                {
                    "content": content,
                    "path": path,
                },
                file_save_file_content_params.FileSaveFileContentParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SaveFileResponse,
        )

    def stream_file(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Stream a file from a specific path.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return self._get(
            f"/files/stream-file/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncFilesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncFilesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncFilesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFilesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncFilesResourceWithStreamingResponse(self)

    async def fetch_download_signed_url(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SignedURL:
        """
        Generate a signed URL for downloading a file from cloud storage.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return await self._get(
            f"/files/fetch-download-signed-url/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SignedURL,
        )

    async def fetch_upload_signed_url(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SignedURL:
        """
        Generate a signed URL for uploading a file to cloud storage.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return await self._get(
            f"/files/fetch-upload-signed-url/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SignedURL,
        )

    async def get_project_node_path(
        self,
        *,
        id: str,
        node_id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Get the path for a node within a specific project.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/files/get_project_node_path/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "id": id,
                        "node_id": node_id,
                        "description": description,
                        "label": label,
                        "location": location,
                        "metadata_version": metadata_version,
                        "status": status,
                    },
                    file_get_project_node_path_params.FileGetProjectNodePathParams,
                ),
            ),
            cast_to=str,
        )

    async def get_simulation_path(
        self,
        *,
        node_id: str,
        sim_global: bool,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Get the initial directory response for simulations (global or user-specific).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/files/get_simulation_path/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "node_id": node_id,
                        "sim_global": sim_global,
                    },
                    file_get_simulation_path_params.FileGetSimulationPathParams,
                ),
            ),
            cast_to=str,
        )

    async def list_directory(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FileListDirectoryResponse:
        """
        List the contents of a directory for a given file path

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return await self._get(
            f"/files/list-directory/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileListDirectoryResponse,
        )

    async def load_editor_file(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> FileLoadEditorFileResponse:
        """
        Load a file from a specific path for the editor.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return await self._get(
            f"/files/load-editor-file/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FileLoadEditorFileResponse,
        )

    async def save_editor_file(
        self,
        *,
        content: str,
        path: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SaveFileResponse:
        """
        Save content to a file in the editor.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/files/save-editor-file",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "path": path,
                },
                file_save_editor_file_params.FileSaveEditorFileParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SaveFileResponse,
        )

    async def save_file_content(
        self,
        file_path: str,
        *,
        content: str,
        path: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SaveFileResponse:
        """
        Save content to a file in the editor.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return await self._post(
            f"/files/content/{file_path}",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "path": path,
                },
                file_save_file_content_params.FileSaveFileContentParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SaveFileResponse,
        )

    async def stream_file(
        self,
        file_path: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Stream a file from a specific path.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not file_path:
            raise ValueError(f"Expected a non-empty value for `file_path` but received {file_path!r}")
        return await self._get(
            f"/files/stream-file/{file_path}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class FilesResourceWithRawResponse:
    def __init__(self, files: FilesResource) -> None:
        self._files = files

        self.fetch_download_signed_url = to_raw_response_wrapper(
            files.fetch_download_signed_url,
        )
        self.fetch_upload_signed_url = to_raw_response_wrapper(
            files.fetch_upload_signed_url,
        )
        self.get_project_node_path = to_raw_response_wrapper(
            files.get_project_node_path,
        )
        self.get_simulation_path = to_raw_response_wrapper(
            files.get_simulation_path,
        )
        self.list_directory = to_raw_response_wrapper(
            files.list_directory,
        )
        self.load_editor_file = to_raw_response_wrapper(
            files.load_editor_file,
        )
        self.save_editor_file = to_raw_response_wrapper(
            files.save_editor_file,
        )
        self.save_file_content = to_raw_response_wrapper(
            files.save_file_content,
        )
        self.stream_file = to_raw_response_wrapper(
            files.stream_file,
        )


class AsyncFilesResourceWithRawResponse:
    def __init__(self, files: AsyncFilesResource) -> None:
        self._files = files

        self.fetch_download_signed_url = async_to_raw_response_wrapper(
            files.fetch_download_signed_url,
        )
        self.fetch_upload_signed_url = async_to_raw_response_wrapper(
            files.fetch_upload_signed_url,
        )
        self.get_project_node_path = async_to_raw_response_wrapper(
            files.get_project_node_path,
        )
        self.get_simulation_path = async_to_raw_response_wrapper(
            files.get_simulation_path,
        )
        self.list_directory = async_to_raw_response_wrapper(
            files.list_directory,
        )
        self.load_editor_file = async_to_raw_response_wrapper(
            files.load_editor_file,
        )
        self.save_editor_file = async_to_raw_response_wrapper(
            files.save_editor_file,
        )
        self.save_file_content = async_to_raw_response_wrapper(
            files.save_file_content,
        )
        self.stream_file = async_to_raw_response_wrapper(
            files.stream_file,
        )


class FilesResourceWithStreamingResponse:
    def __init__(self, files: FilesResource) -> None:
        self._files = files

        self.fetch_download_signed_url = to_streamed_response_wrapper(
            files.fetch_download_signed_url,
        )
        self.fetch_upload_signed_url = to_streamed_response_wrapper(
            files.fetch_upload_signed_url,
        )
        self.get_project_node_path = to_streamed_response_wrapper(
            files.get_project_node_path,
        )
        self.get_simulation_path = to_streamed_response_wrapper(
            files.get_simulation_path,
        )
        self.list_directory = to_streamed_response_wrapper(
            files.list_directory,
        )
        self.load_editor_file = to_streamed_response_wrapper(
            files.load_editor_file,
        )
        self.save_editor_file = to_streamed_response_wrapper(
            files.save_editor_file,
        )
        self.save_file_content = to_streamed_response_wrapper(
            files.save_file_content,
        )
        self.stream_file = to_streamed_response_wrapper(
            files.stream_file,
        )


class AsyncFilesResourceWithStreamingResponse:
    def __init__(self, files: AsyncFilesResource) -> None:
        self._files = files

        self.fetch_download_signed_url = async_to_streamed_response_wrapper(
            files.fetch_download_signed_url,
        )
        self.fetch_upload_signed_url = async_to_streamed_response_wrapper(
            files.fetch_upload_signed_url,
        )
        self.get_project_node_path = async_to_streamed_response_wrapper(
            files.get_project_node_path,
        )
        self.get_simulation_path = async_to_streamed_response_wrapper(
            files.get_simulation_path,
        )
        self.list_directory = async_to_streamed_response_wrapper(
            files.list_directory,
        )
        self.load_editor_file = async_to_streamed_response_wrapper(
            files.load_editor_file,
        )
        self.save_editor_file = async_to_streamed_response_wrapper(
            files.save_editor_file,
        )
        self.save_file_content = async_to_streamed_response_wrapper(
            files.save_file_content,
        )
        self.stream_file = async_to_streamed_response_wrapper(
            files.stream_file,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .logs import (
    LogsResource,
    AsyncLogsResource,
    LogsResourceWithRawResponse,
    AsyncLogsResourceWithRawResponse,
    LogsResourceWithStreamingResponse,
    AsyncLogsResourceWithStreamingResponse,
)
from .runs import (
    RunsResource,
    AsyncRunsResource,
    RunsResourceWithRawResponse,
    AsyncRunsResourceWithRawResponse,
    RunsResourceWithStreamingResponse,
    AsyncRunsResourceWithStreamingResponse,
)

__all__ = [
    "LogsResource",
    "AsyncLogsResource",
    "LogsResourceWithRawResponse",
    "AsyncLogsResourceWithRawResponse",
    "LogsResourceWithStreamingResponse",
    "AsyncLogsResourceWithStreamingResponse",
    "RunsResource",
    "AsyncRunsResource",
    "RunsResourceWithRawResponse",
    "AsyncRunsResourceWithRawResponse",
    "RunsResourceWithStreamingResponse",
    "AsyncRunsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .auth import (
    AuthResource,
    AsyncAuthResource,
    AuthResourceWithRawResponse,
    AsyncAuthResourceWithRawResponse,
    AuthResourceWithStreamingResponse,
    AsyncAuthResourceWithStreamingResponse,
)
from .runs import (
    RunsResource,
    AsyncRunsResource,
    RunsResourceWithRawResponse,
    AsyncRunsResourceWithRawResponse,
    RunsResourceWithStreamingResponse,
    AsyncRunsResourceWithStreamingResponse,
)
from .candy import (
    CandyResource,
    AsyncCandyResource,
    CandyResourceWithRawResponse,
    AsyncCandyResourceWithRawResponse,
    CandyResourceWithStreamingResponse,
    AsyncCandyResourceWithStreamingResponse,
)
from .files import (
    FilesResource,
    AsyncFilesResource,
    FilesResourceWithRawResponse,
    AsyncFilesResourceWithRawResponse,
    FilesResourceWithStreamingResponse,
    AsyncFilesResourceWithStreamingResponse,
)
from .graph import (
    GraphResource,
    AsyncGraphResource,
    GraphResourceWithRawResponse,
    AsyncGraphResourceWithRawResponse,
    GraphResourceWithStreamingResponse,
    AsyncGraphResourceWithStreamingResponse,
)
from .utils import (
    UtilsResource,
    AsyncUtilsResource,
    UtilsResourceWithRawResponse,
    AsyncUtilsResourceWithRawResponse,
    UtilsResourceWithStreamingResponse,
    AsyncUtilsResourceWithStreamingResponse,
)
from .projects import (
    ProjectsResource,
    AsyncProjectsResource,
    ProjectsResourceWithRawResponse,
    AsyncProjectsResourceWithRawResponse,
    ProjectsResourceWithStreamingResponse,
    AsyncProjectsResourceWithStreamingResponse,
)
from .simulation import (
    SimulationResource,
    AsyncSimulationResource,
    SimulationResourceWithRawResponse,
    AsyncSimulationResourceWithRawResponse,
    SimulationResourceWithStreamingResponse,
    AsyncSimulationResourceWithStreamingResponse,
)
from .test_connection import (
    TestConnectionResource,
    AsyncTestConnectionResource,
    TestConnectionResourceWithRawResponse,
    AsyncTestConnectionResourceWithRawResponse,
    TestConnectionResourceWithStreamingResponse,
    AsyncTestConnectionResourceWithStreamingResponse,
)
from .list_environments import (
    ListEnvironmentsResource,
    AsyncListEnvironmentsResource,
    ListEnvironmentsResourceWithRawResponse,
    AsyncListEnvironmentsResourceWithRawResponse,
    ListEnvironmentsResourceWithStreamingResponse,
    AsyncListEnvironmentsResourceWithStreamingResponse,
)
from .upsert_simulation import (
    UpsertSimulationResource,
    AsyncUpsertSimulationResource,
    UpsertSimulationResourceWithRawResponse,
    AsyncUpsertSimulationResourceWithRawResponse,
    UpsertSimulationResourceWithStreamingResponse,
    AsyncUpsertSimulationResourceWithStreamingResponse,
)

__all__ = [
    "TestConnectionResource",
    "AsyncTestConnectionResource",
    "TestConnectionResourceWithRawResponse",
    "AsyncTestConnectionResourceWithRawResponse",
    "TestConnectionResourceWithStreamingResponse",
    "AsyncTestConnectionResourceWithStreamingResponse",
    "CandyResource",
    "AsyncCandyResource",
    "CandyResourceWithRawResponse",
    "AsyncCandyResourceWithRawResponse",
    "CandyResourceWithStreamingResponse",
    "AsyncCandyResourceWithStreamingResponse",
    "GraphResource",
    "AsyncGraphResource",
    "GraphResourceWithRawResponse",
    "AsyncGraphResourceWithRawResponse",
    "GraphResourceWithStreamingResponse",
    "AsyncGraphResourceWithStreamingResponse",
    "ProjectsResource",
    "AsyncProjectsResource",
    "ProjectsResourceWithRawResponse",
    "AsyncProjectsResourceWithRawResponse",
    "ProjectsResourceWithStreamingResponse",
    "AsyncProjectsResourceWithStreamingResponse",
    "FilesResource",
    "AsyncFilesResource",
    "FilesResourceWithRawResponse",
    "AsyncFilesResourceWithRawResponse",
    "FilesResourceWithStreamingResponse",
    "AsyncFilesResourceWithStreamingResponse",
    "RunsResource",
    "AsyncRunsResource",
    "RunsResourceWithRawResponse",
    "AsyncRunsResourceWithRawResponse",
    "RunsResourceWithStreamingResponse",
    "AsyncRunsResourceWithStreamingResponse",
    "AuthResource",
    "AsyncAuthResource",
    "AuthResourceWithRawResponse",
    "AsyncAuthResourceWithRawResponse",
    "AuthResourceWithStreamingResponse",
    "AsyncAuthResourceWithStreamingResponse",
    "ListEnvironmentsResource",
    "AsyncListEnvironmentsResource",
    "ListEnvironmentsResourceWithRawResponse",
    "AsyncListEnvironmentsResourceWithRawResponse",
    "ListEnvironmentsResourceWithStreamingResponse",
    "AsyncListEnvironmentsResourceWithStreamingResponse",
    "UpsertSimulationResource",
    "AsyncUpsertSimulationResource",
    "UpsertSimulationResourceWithRawResponse",
    "AsyncUpsertSimulationResourceWithRawResponse",
    "UpsertSimulationResourceWithStreamingResponse",
    "AsyncUpsertSimulationResourceWithStreamingResponse",
    "UtilsResource",
    "AsyncUtilsResource",
    "UtilsResourceWithRawResponse",
    "AsyncUtilsResourceWithRawResponse",
    "UtilsResourceWithStreamingResponse",
    "AsyncUtilsResourceWithStreamingResponse",
    "SimulationResource",
    "AsyncSimulationResource",
    "SimulationResourceWithRawResponse",
    "AsyncSimulationResourceWithRawResponse",
    "SimulationResourceWithStreamingResponse",
    "AsyncSimulationResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import datetime
from typing import List, Optional

from .._models import BaseModel

__all__ = ["NodeMetadataSimulation", "Author", "Tag"]


class Author(BaseModel):
    institution: str

    name: str

    email: Optional[str] = None


class Tag(BaseModel):
    name: str

    color: Optional[str] = None

    description: Optional[str] = None

    icon: Optional[str] = None


class NodeMetadataSimulation(BaseModel):
    id: str

    authors: List[Author]

    date: Optional[datetime.date] = None

    description: str

    name: str

    tags: List[Tag]

    version: str

    code_url: Optional[str] = None

    metadata_version: Optional[str] = None

    mlflow_run_id: Optional[str] = None

    paper_url: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["SSHConnectResponse"]


class SSHConnectResponse(BaseModel):
    connected: bool

    message: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import project_upsert_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.project_summary import ProjectSummary
from ..types.project_list_response import ProjectListResponse

__all__ = ["ProjectsResource", "AsyncProjectsResource"]


class ProjectsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ProjectsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return ProjectsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ProjectsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return ProjectsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        project_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProjectSummary:
        """
        Get a project by its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not project_id:
            raise ValueError(f"Expected a non-empty value for `project_id` but received {project_id!r}")
        return self._get(
            f"/projects/{project_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProjectSummary,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProjectListResponse:
        """Get a summary of all projects."""
        return self._get(
            "/projects",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProjectListResponse,
        )

    def delete(
        self,
        project_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Delete a project based on its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not project_id:
            raise ValueError(f"Expected a non-empty value for `project_id` but received {project_id!r}")
        return self._delete(
            f"/projects/{project_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def sync(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Sync all projects from file system to Firestore.

        Treats file system as the
        source of truth and overwrites Firestore data.
        """
        return self._post(
            "/projects/sync",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def upsert(
        self,
        *,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProjectSummary:
        """
        Create or update a project.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._put(
            "/projects/insert_project",
            body=maybe_transform(
                {
                    "id": id,
                    "description": description,
                    "label": label,
                    "location": location,
                    "metadata_version": metadata_version,
                    "status": status,
                },
                project_upsert_params.ProjectUpsertParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProjectSummary,
        )


class AsyncProjectsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncProjectsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncProjectsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncProjectsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncProjectsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        project_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProjectSummary:
        """
        Get a project by its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not project_id:
            raise ValueError(f"Expected a non-empty value for `project_id` but received {project_id!r}")
        return await self._get(
            f"/projects/{project_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProjectSummary,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProjectListResponse:
        """Get a summary of all projects."""
        return await self._get(
            "/projects",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProjectListResponse,
        )

    async def delete(
        self,
        project_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Delete a project based on its ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not project_id:
            raise ValueError(f"Expected a non-empty value for `project_id` but received {project_id!r}")
        return await self._delete(
            f"/projects/{project_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def sync(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Sync all projects from file system to Firestore.

        Treats file system as the
        source of truth and overwrites Firestore data.
        """
        return await self._post(
            "/projects/sync",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def upsert(
        self,
        *,
        id: str,
        description: str | NotGiven = NOT_GIVEN,
        label: str | NotGiven = NOT_GIVEN,
        location: str | NotGiven = NOT_GIVEN,
        metadata_version: str | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ProjectSummary:
        """
        Create or update a project.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._put(
            "/projects/insert_project",
            body=await async_maybe_transform(
                {
                    "id": id,
                    "description": description,
                    "label": label,
                    "location": location,
                    "metadata_version": metadata_version,
                    "status": status,
                },
                project_upsert_params.ProjectUpsertParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProjectSummary,
        )


class ProjectsResourceWithRawResponse:
    def __init__(self, projects: ProjectsResource) -> None:
        self._projects = projects

        self.retrieve = to_raw_response_wrapper(
            projects.retrieve,
        )
        self.list = to_raw_response_wrapper(
            projects.list,
        )
        self.delete = to_raw_response_wrapper(
            projects.delete,
        )
        self.sync = to_raw_response_wrapper(
            projects.sync,
        )
        self.upsert = to_raw_response_wrapper(
            projects.upsert,
        )


class AsyncProjectsResourceWithRawResponse:
    def __init__(self, projects: AsyncProjectsResource) -> None:
        self._projects = projects

        self.retrieve = async_to_raw_response_wrapper(
            projects.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            projects.list,
        )
        self.delete = async_to_raw_response_wrapper(
            projects.delete,
        )
        self.sync = async_to_raw_response_wrapper(
            projects.sync,
        )
        self.upsert = async_to_raw_response_wrapper(
            projects.upsert,
        )


class ProjectsResourceWithStreamingResponse:
    def __init__(self, projects: ProjectsResource) -> None:
        self._projects = projects

        self.retrieve = to_streamed_response_wrapper(
            projects.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            projects.list,
        )
        self.delete = to_streamed_response_wrapper(
            projects.delete,
        )
        self.sync = to_streamed_response_wrapper(
            projects.sync,
        )
        self.upsert = to_streamed_response_wrapper(
            projects.upsert,
        )


class AsyncProjectsResourceWithStreamingResponse:
    def __init__(self, projects: AsyncProjectsResource) -> None:
        self._projects = projects

        self.retrieve = async_to_streamed_response_wrapper(
            projects.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            projects.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            projects.delete,
        )
        self.sync = async_to_streamed_response_wrapper(
            projects.sync,
        )
        self.upsert = async_to_streamed_response_wrapper(
            projects.upsert,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

from .parameter_param import ParameterParam

__all__ = ["GraphSetParametersParams"]


class GraphSetParametersParams(TypedDict, total=False):
    id: Required[str]

    body: Required[Iterable[ParameterParam]]

    description: str

    label: str

    location: str

    metadata_version: str

    status: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["Parameter", "Option"]


class Option(BaseModel):
    label: str

    value: str


class Parameter(BaseModel):
    description: str

    label: str

    name: str

    type: str

    value: str

    latex: Optional[str] = None

    location: Optional[List[str]] = None

    options: Optional[List[Option]] = None

    scope: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.auth import ssh_connect_params
from ..._base_client import make_request_options
from ...types.auth.ssh_connect_response import SSHConnectResponse

__all__ = ["SSHResource", "AsyncSSHResource"]


class SSHResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SSHResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return SSHResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SSHResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return SSHResourceWithStreamingResponse(self)

    def connect(
        self,
        *,
        password: str,
        username: str,
        verification_code: str,
        host: str | NotGiven = NOT_GIVEN,
        port: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SSHConnectResponse:
        """
        Establish an SSH connection to the cluster using username, password, and 2FA.
        This connection will be stored for subsequent operations.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/auth/ssh/connect",
            body=maybe_transform(
                {
                    "password": password,
                    "username": username,
                    "verification_code": verification_code,
                    "host": host,
                    "port": port,
                },
                ssh_connect_params.SSHConnectParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SSHConnectResponse,
        )

    def disconnect(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Disconnect all persistent SSH connections."""
        return self._post(
            "/auth/ssh/disconnect",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Check if we have any active SSH connections."""
        return self._get(
            "/auth/ssh/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncSSHResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSSHResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSSHResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSSHResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncSSHResourceWithStreamingResponse(self)

    async def connect(
        self,
        *,
        password: str,
        username: str,
        verification_code: str,
        host: str | NotGiven = NOT_GIVEN,
        port: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SSHConnectResponse:
        """
        Establish an SSH connection to the cluster using username, password, and 2FA.
        This connection will be stored for subsequent operations.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/auth/ssh/connect",
            body=await async_maybe_transform(
                {
                    "password": password,
                    "username": username,
                    "verification_code": verification_code,
                    "host": host,
                    "port": port,
                },
                ssh_connect_params.SSHConnectParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SSHConnectResponse,
        )

    async def disconnect(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Disconnect all persistent SSH connections."""
        return await self._post(
            "/auth/ssh/disconnect",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Check if we have any active SSH connections."""
        return await self._get(
            "/auth/ssh/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class SSHResourceWithRawResponse:
    def __init__(self, ssh: SSHResource) -> None:
        self._ssh = ssh

        self.connect = to_raw_response_wrapper(
            ssh.connect,
        )
        self.disconnect = to_raw_response_wrapper(
            ssh.disconnect,
        )
        self.status = to_raw_response_wrapper(
            ssh.status,
        )


class AsyncSSHResourceWithRawResponse:
    def __init__(self, ssh: AsyncSSHResource) -> None:
        self._ssh = ssh

        self.connect = async_to_raw_response_wrapper(
            ssh.connect,
        )
        self.disconnect = async_to_raw_response_wrapper(
            ssh.disconnect,
        )
        self.status = async_to_raw_response_wrapper(
            ssh.status,
        )


class SSHResourceWithStreamingResponse:
    def __init__(self, ssh: SSHResource) -> None:
        self._ssh = ssh

        self.connect = to_streamed_response_wrapper(
            ssh.connect,
        )
        self.disconnect = to_streamed_response_wrapper(
            ssh.disconnect,
        )
        self.status = to_streamed_response_wrapper(
            ssh.status,
        )


class AsyncSSHResourceWithStreamingResponse:
    def __init__(self, ssh: AsyncSSHResource) -> None:
        self._ssh = ssh

        self.connect = async_to_streamed_response_wrapper(
            ssh.connect,
        )
        self.disconnect = async_to_streamed_response_wrapper(
            ssh.disconnect,
        )
        self.status = async_to_streamed_response_wrapper(
            ssh.status,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .node_metadata_simulation import NodeMetadataSimulation

__all__ = ["RunFetchRunNodesResponse"]

RunFetchRunNodesResponse: TypeAlias = List[NodeMetadataSimulation]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Required, TypedDict

__all__ = ["UpsertSimulationCreateParams", "EnvironmentVariable", "PackageManager"]


class UpsertSimulationCreateParams(TypedDict, total=False):
    container_image: Required[str]

    environment_variables: Required[Iterable[EnvironmentVariable]]

    name: Required[str]

    package_managers: Required[Iterable[PackageManager]]

    post_install_script: Required[str]


class EnvironmentVariable(TypedDict, total=False):
    key: Required[str]

    value: Required[str]


class PackageManager(TypedDict, total=False):
    name: Required[str]

    packages: Required[List[str]]

    version: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.runs import log_stream_params
from ..._base_client import make_request_options

__all__ = ["LogsResource", "AsyncLogsResource"]


class LogsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LogsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return LogsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LogsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return LogsResourceWithStreamingResponse(self)

    def stream(
        self,
        run_id: str,
        *,
        token: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Stream live logs for a specific run using Server-Sent Events (SSE).

        All node
        logs appear sequentially with node prefixes.

        Note: Token parameter is used for auth since EventSource doesn't support
        headers.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not run_id:
            raise ValueError(f"Expected a non-empty value for `run_id` but received {run_id!r}")
        return self._get(
            f"/runs/logs/{run_id}/stream",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"token": token}, log_stream_params.LogStreamParams),
            ),
            cast_to=object,
        )


class AsyncLogsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLogsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncLogsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLogsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Fluidize-Inc/fluidize-python-sdk#with_streaming_response
        """
        return AsyncLogsResourceWithStreamingResponse(self)

    async def stream(
        self,
        run_id: str,
        *,
        token: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """Stream live logs for a specific run using Server-Sent Events (SSE).

        All node
        logs appear sequentially with node prefixes.

        Note: Token parameter is used for auth since EventSource doesn't support
        headers.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not run_id:
            raise ValueError(f"Expected a non-empty value for `run_id` but received {run_id!r}")
        return await self._get(
            f"/runs/logs/{run_id}/stream",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"token": token}, log_stream_params.LogStreamParams),
            ),
            cast_to=object,
        )


class LogsResourceWithRawResponse:
    def __init__(self, logs: LogsResource) -> None:
        self._logs = logs

        self.stream = to_raw_response_wrapper(
            logs.stream,
        )


class AsyncLogsResourceWithRawResponse:
    def __init__(self, logs: AsyncLogsResource) -> None:
        self._logs = logs

        self.stream = async_to_raw_response_wrapper(
            logs.stream,
        )


class LogsResourceWithStreamingResponse:
    def __init__(self, logs: LogsResource) -> None:
        self._logs = logs

        self.stream = to_streamed_response_wrapper(
            logs.stream,
        )


class AsyncLogsResourceWithStreamingResponse:
    def __init__(self, logs: AsyncLogsResource) -> None:
        self._logs = logs

        self.stream = async_to_streamed_response_wrapper(
            logs.stream,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["FileListDirectoryResponse", "Item"]


class Item(BaseModel):
    name: str

    path: str

    type: Literal["directory", "file"]

    last_modified: Optional[float] = None

    size: Optional[int] = None


class FileListDirectoryResponse(BaseModel):
    items: List[Item]

    total_count: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .parameter import Parameter

__all__ = ["GraphSetParametersResponse"]

GraphSetParametersResponse: TypeAlias = List[Parameter]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel
from .graph_edge import GraphEdge
from .graph_node import GraphNode

__all__ = ["GraphRetrieveResponse"]


class GraphRetrieveResponse(BaseModel):
    edges: List[GraphEdge]

    nodes: List[GraphNode]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["ProjectSummary"]


class ProjectSummary(BaseModel):
    id: str

    description: Optional[str] = None

    label: Optional[str] = None

    location: Optional[str] = None

    metadata_version: Optional[str] = None

    status: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["GraphNodeParam", "Data", "Position"]


class Data(TypedDict, total=False):
    label: Required[str]

    simulation_id: Optional[str]


class Position(TypedDict, total=False):
    x: Required[float]

    y: Required[float]


class GraphNodeParam(TypedDict, total=False):
    id: Required[str]

    data: Required[Data]
    """Extra metadata for a node."""

    position: Required[Position]
    """Position of a node in layout space."""

    type: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["FileGetSimulationPathParams"]


class FileGetSimulationPathParams(TypedDict, total=False):
    node_id: Required[str]

    sim_global: Required[bool]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .project_summary import ProjectSummary

__all__ = ["ProjectListResponse"]

ProjectListResponse: TypeAlias = List[ProjectSummary]
